darkhistory.low_energy.lowE_photons.get_kappa_2s — DarkHistory documentation

# darkhistory.low_energy.lowE_photons.get_kappa_2s

`darkhistory.low_energy.lowE_photons.` `get_kappa_2s`(photspec)

  Compute kappa_2s for use in kappa_DM function

  Parameters: | photspec : Spectrum object spectrum of photons. spec.toteng() should return Energy per baryon.
  Returns: | kappa_2s : float The added photoionization rate from the 1s to the 2s state due to DM photons.

### This Page

Show Source